@@ -1,4 +1,4 @@
-/* Copyright (c) 2017 - 2020 LiteSpeed Technologies Inc.  See LICENSE. */
+/* Copyright (c) 2017 - 2021 LiteSpeed Technologies Inc.  See LICENSE. */
 #include <time.h>
 #ifdef WIN32
 #include <vc_compat.h>
@@ -43,7 +43,7 @@ log_hist_slice (const struct hist_slice *slice, time_t t)
 
 
 void
-eng_hist_log (const struct eng_hist *hist)
+lsquic_eng_hist_log (const struct eng_hist *hist)
 {
     unsigned i, idx;
     time_t t0 = time(NULL) - ENG_HIST_NELEMS + 1;
