@@ -1,4 +1,4 @@
-/* Copyright (c) 2017 - 2020 LiteSpeed Technologies Inc.  See LICENSE. */
+/* Copyright (c) 2017 - 2021 LiteSpeed Technologies Inc.  See LICENSE. */
 /*
  * lsquic_pr_queue.c -- packet request queue.
  */
@@ -6,11 +6,14 @@
 #include <assert.h>
 #include <errno.h>
 #include <inttypes.h>
-#include <netinet/in.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/queue.h>
+
+#ifndef WIN32
+#include <netinet/in.h>
 #include <sys/socket.h>
+#endif
 
 #include <openssl/aead.h>
 #include <openssl/rand.h>
@@ -135,7 +138,7 @@ hash_req (const void *p, size_t len, unsigned seed)
 
 
 struct pr_queue *
-prq_create (unsigned max_elems, unsigned max_conns,
+lsquic_prq_create (unsigned max_elems, unsigned max_conns,
                         const struct lsquic_engine_public *enpub)
 {
     const struct parse_funcs *pf;
@@ -217,7 +220,7 @@ prq_create (unsigned max_elems, unsigned max_conns,
 
 
 void
-prq_destroy (struct pr_queue *prq)
+lsquic_prq_destroy (struct pr_queue *prq)
 {
     struct lsquic_conn *conn;
 
@@ -259,8 +262,8 @@ put_req (struct pr_queue *prq, struct packet_req *req)
 }
 
 
-int
-lsquic_prq_new_req (struct pr_queue *prq, enum packet_req_type type,
+static int
+lsquic_prq_new_req_ext (struct pr_queue *prq, enum packet_req_type type,
     unsigned flags, enum lsquic_version version, unsigned short data_sz,
     const lsquic_cid_t *dcid, const lsquic_cid_t *scid, void *peer_ctx,
     const struct sockaddr *local_addr, const struct sockaddr *peer_addr)
@@ -334,7 +337,7 @@ lsquic_prq_new_req (struct pr_queue *prq, enum packet_req_type type,
 
 
 int
-prq_new_req (struct pr_queue *prq, enum packet_req_type type,
+lsquic_prq_new_req (struct pr_queue *prq, enum packet_req_type type,
          const struct lsquic_packet_in *packet_in, void *peer_ctx,
          const struct sockaddr *local_addr, const struct sockaddr *peer_addr)
 {
@@ -355,11 +358,12 @@ prq_new_req (struct pr_queue *prq, enum packet_req_type type,
         version = lsquic_tag2ver(ver_tag);
     }
     else /* Got to set it to something sensible... */
-        version = LSQVER_ID25;
+        version = LSQVER_ID27;
 
     lsquic_scid_from_packet_in(packet_in, &scid);
-    return lsquic_prq_new_req(prq, type, flags, version, packet_in->pi_data_sz,
-                &packet_in->pi_dcid, &scid, peer_ctx, local_addr, peer_addr);
+    return lsquic_prq_new_req_ext(prq, type, flags, version,
+                packet_in->pi_data_sz, &packet_in->pi_dcid, &scid,
+                peer_ctx, local_addr, peer_addr);
 }
 
 
@@ -421,7 +425,7 @@ get_evconn (struct pr_queue *prq)
 
 
 struct lsquic_conn *
-prq_next_conn (struct pr_queue *prq)
+lsquic_prq_next_conn (struct pr_queue *prq)
 {
     struct evanescent_conn *evconn;
     struct lsquic_conn *lconn;
@@ -504,17 +508,18 @@ prq_next_conn (struct pr_queue *prq)
 
 
 int
-prq_have_pending (const struct pr_queue *prq)
+lsquic_prq_have_pending (const struct pr_queue *prq)
 {
     return lsquic_hash_count(prq->prq_reqs_hash) > 0;
 }
 
 
 static struct lsquic_packet_out *
-evanescent_conn_ci_next_packet_to_send (struct lsquic_conn *lconn, size_t size)
+evanescent_conn_ci_next_packet_to_send (struct lsquic_conn *lconn,
+                                        const struct to_coal *to_coal_UNUSED)
 {
     struct evanescent_conn *const evconn = (struct evanescent_conn *) lconn;
-    assert(size == 0);
+    assert(!to_coal_UNUSED);
     return &evconn->evc_packet_out;
 }
 
