@@ -1,4 +1,4 @@
-/* Copyright (c) 2017 - 2020 LiteSpeed Technologies Inc.  See LICENSE. */
+/* Copyright (c) 2017 - 2021 LiteSpeed Technologies Inc.  See LICENSE. */
 /*
  * lsquic_qlog.h -- QLOG Event logger
  */
@@ -10,6 +10,8 @@
 #include "lsquic_packet_common.h"
 #include "lsquic_str.h"
 
+struct stack_st_X509;
+
 /*
 EventCategory
     CONNECTIVITY
@@ -78,11 +80,14 @@ void
 lsquic_qlog_hsk_completed (const lsquic_cid_t *);
 
 void
-lsquic_qlog_zero_rtt (const lsquic_cid_t *);
+lsquic_qlog_sess_resume (const lsquic_cid_t *);
 
 void
 lsquic_qlog_check_certs (const lsquic_cid_t *, const lsquic_str_t **, size_t);
 
+void
+lsquic_qlog_cert_chain (const lsquic_cid_t *, struct stack_st_X509 *);
+
 void
 lsquic_qlog_version_negotiation (const lsquic_cid_t *, const char *, const char *);
 
